# -*- coding: utf-8 -*-
"""
The thermosteam.reaction package features objects to manage stoichiometric reactions and conversions.
"""

from . import _reaction

__all__ = (*_reaction.__all__,)

from ._reaction import *

#: Whether or not to check reaction feasibility.
CHECK_FEASIBILITY = True